@@ -139,6 +139,7 @@ sub init {
     Shipwright::Logger->new( log_level => 'FATAL' );
     $ENV{'SHIPWRIGHT_SVK'} ||= 'svk';
     $ENV{'SHIPWRIGHT_SVN'} ||= 'svn';
+    $ENV{'SHIPWRIGHT_GIT'} ||= 'git';
 }
 
 =head2 shipwright_bin
@@ -175,7 +176,6 @@ a simple wrap for test cmd like create, list ...
 =cut
 
 sub test_cmd {
-    my $repo    = shift;
     my $cmd     = shift;
     my $exp     = shift;
     my $msg     = shift || "@$cmd out";
